window.Gleam.initSearch([{"doc":"glacier","title":"glacier","content":"# Glacier · Gleam Incremental Interactive Unit Testing\n\n[![Hex Package](https://img.shields.io/hexpm/v/glacier?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glacier)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glacier/)\n[![License](https://img.shields.io/hexpm/l/glacier?color=ffaff3&amp;label=%F0%9F%93%83)](https://github.com/inoas/glacier/blob/main/LICENSE)\n\n**Glacier** brings incremental interactive unit testing to [Gleam](https://gleam.run).\nIt is meant as a drop-in replacement for [Gleeunit](https://hexdocs.pm/gleeunit) and it relies on it, internally.\n\n&lt;figure&gt;\n\t&lt;img src=&quot;https://raw.githubusercontent.com/inoas/glacier/main/glacier-logo.png&quot; alt=&quot;Glacier Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n  &lt;figcaption&gt;&lt;i&gt;&lt;small&gt;Glacier: &lt;a href=&quot;https://en.wikipedia.org/wiki/Glacier&quot;&gt;«A persistent body of dense ice that is constantly moving under its own weight.»&lt;/a&gt;&lt;/small&gt;&lt;/i&gt;&lt;/figcaption&gt;\n&lt;/figure&gt;\n\n## Quick start\n\n1. Run `gleam add glacier --dev`.\n2. Open `./test/YOUR_PROJECT.gleam` and replace `import gleeunit` with `import glacier` and `gleeunit.main()` with `glacier.main()`.\n3. Run `gleam test --target erlang -- --glacier` or `gleam test --target javascript -- --glacier`.\n4. Save a `src` or `test` module and watch associated tests to re-run.\n\n*Notice: On Linux [**inotify**](https://en.wikipedia.org/wiki/Inotify) must be installed.*\n\n## Introduction\n\n**Glacier** differs from **Gleeunit** insofar, that it let&#39;s you:\n\n1. Pass in the `glacier` flag like so: `gleam test -- --glacier`, save a module and only related tests will rerun.\n2. Or Pass in a specific unit test modules to rerun `gleam test -- test/my_module_test.gleam`.\n3. If `gleam test` is passed without any `--`-arguments it behaves the same as **Gleeunit**.\n4. You can still pass in `--target erlang` or `--target javascript` like so `gleam test --target erlang -- --glacier`, or like `gleam test --target javascript -- test/my_module_test.gleam`.\n\nTo enable this behavior, all you have to do is add **Glacier** as a dev dependency, aka `gleam add glacier --dev`, open `./test/YOUR_PROJECT.gleam` and replace `gleeunit.main()` with `glacier.main()`.\n\n*Note: `gleam test` must only be executed from the base project directory!*\n\n### Testing against Erlang &amp; JavaScript\n\nRun `gleam test --target erlang -- --glacier` and `gleam test --target javascript -- --glacier` in two terminals side by side.\n\n## Requirements, Installation &amp; Usage\n\n### Requirements\n\nRequires Gleam 0.25 or later.\n\n#### Target Erlang\n\nDevelopment and testing only happens on very recent stable Erlang/OTP versions, and thus may or may not run on previous versions.\n\nDepends on [fs](https://hexdocs.pm/fs/):\n\n- Linux [relies](https://github.com/synrc/fs#backends) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n#### Target JavaScript/NodeJS\n\nDevelopment and testing only happens on very recent NodeJS LTS versions, and thus may or may not run on previous versions.\n\nDepends on [`fsPromises.watch`](https://nodejs.org/api/fs.html#fspromiseswatchfilename-options):\n\n- Linux: [relies](https://nodejs.org/docs/latest-v18.x/api/fs.html#fs_caveats) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n[**Deno**](https://deno.land) is not yet supported.\n\n### Installation\n\nThis package is available on [hex.pm](https://hex.pm) can be added to your Gleam project:\n\nRun `gleam add glacier --dev`.\n\n### Usage\n\n1. Open `./test/YOUR_PROJECT.gleam` and replace `import gleeunit` with `import glacier` and `gleeunit.main()` with `glacier.main()`.\n2. Run `gleam test -- --glacier`, then:\n   - Save any test module (within `./test`) file to re-run that single test\n   - Save any src module (within `./src`) to run all associated tests. Associated tests are test modules where the module is imported or where any of the module&#39;s imports and their import&#39;s imports (import chain) are imported into.\n3. Optional: You may find and replace all `import gleeunit/should` with `import glacier/should` and remove `gleeunit` from your dependencies in `gleam.toml`.\n\n## Documentation\n\nDocumentation can be found at &lt;https://hexdocs.pm/glacier&gt;.\n\n### How does it work?\n\n1. `gleam test` passes through `glacier.main()` and simply executes `gleeunit.main()` as if **Gleeunit** was used directly.\n2. `gleam test -- test_module_a test_module_b` passes through `glacier.main()` and executes `gleeunit.test_modules(modules_list)` where `modules_list` is `[&quot;foo&quot;, &quot;bar&quot;]`. The given modules are checked if they exist as either `.gleam` or `.erl` test module files and then **Gleeunit** runs these test modules.\n3. `gleam test -- --glacier` enters `glacier.main()` and starts a file watcher: Upon changes in module files in `./test` it just passes those through as `gleam test -- changed_test_module`(so re-saving test files executes the single test), and if a module file in `./src` got changed it parses that changed module file for any imported modules and puts the module and all chained imported modules in a distinct list of modules that should be tested. Then all test module files are read and imports of those are gathered one by one and cross matched against that list. The result is a list of test modules that need to be run, which then gets done by executing a shell call similar to `gleam test -- detected_test_module_a detected_test_module_b detected_test_module_c etc`, aka jump to step `2`.\n\n## Developing Glacier\n\n```sh\ngit clone https://github.com/inoas/glacier.git\ncd glacier\n```\n\nSee all [open issues](https://github.com/inoas/glacier/issues) on GitHub if you want to help out.\n\n### Demo for target Erlang\n\n```sh\n# Traditional test runs\ngleam test --target erlang\ngleam test --target erlang -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target erlang -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n### Demo for target JavaScript/NodeJS\n\n```sh\n# Traditional test runs\ngleam test --target javascript\ngleam test --target javascript -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target javascript -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n## License\n\n[Apache 2.0](./LICENSE)\n","url":"index.html"},{"doc":"glacier","title":"glacier","content":"# Changelog\n\n## 0.2.7\n\n- Fix `MaxListenersExceededWarning: Possible EventEmitter memory leak detected` (#4).\n- Cleanup `README.md`.\n\n## 0.2.6\n\n- Instruct to use `gleam add glacier --dev` to add as a dev dependency, only.\n\n## 0.2.5\n\n- Readme: Explain that `gleeunit` is optional if `glacier` is installed if `gleeunit/should` is replaced by `glacier/should`.\n\n## 0.2.4\n\n- More compatibility changes to run `glacier` alongside `gleeunit`:\n  Added `glacier/should` which is a renamed `gleeunit/should`.\n\n## 0.2.3\n\n- Remove code that did nothing.\n\n## 0.2.2\n\n- Fixed `README.md`.\n\n## 0.2.1\n\n- Fixed `README.md`.\n\n## 0.2.0\n\n- Added `CHANGELOG.md`.\n- Renamed internal gleeunit fork to gleeunit2 to avoid collisions.\n- JavaScript: File renames are picked up by the watcher.\n- Replaced `glacier.run()` with `glacier.main()` as latter did not make sense before.\n- Fixed `README.md`.\n- Fixed the logo to work across hexpm and github and shields badges.\n","url":"changelog.html"},{"doc":"glacier","title":"glacier","content":"                                 Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      &quot;License&quot; shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      &quot;Legal Entity&quot; shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      &quot;control&quot; means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      &quot;Source&quot; form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      &quot;Object&quot; form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      &quot;Work&quot; shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      &quot;Contribution&quot; shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, &quot;submitted&quot;\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;\n\n      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n","url":"license.html"},{"doc":"glacier_demo/glacier_demo_module_a","title":"function_1","content":"pub fn function_1() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_a.function_1\nglacier_demo/glacier_demo_module_a function_1","url":"glacier_demo/glacier_demo_module_a.html#function_1"},{"doc":"glacier_demo/glacier_demo_module_a","title":"function_2","content":"pub fn function_2() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_a.function_2\nglacier_demo/glacier_demo_module_a function_2","url":"glacier_demo/glacier_demo_module_a.html#function_2"},{"doc":"glacier_demo/glacier_demo_module_a","title":"glacier_demo/glacier_demo_module_a","content":"","url":"glacier_demo/glacier_demo_module_a.html"},{"doc":"glacier_demo/glacier_demo_module_d","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_d.main\nglacier_demo/glacier_demo_module_d main","url":"glacier_demo/glacier_demo_module_d.html#main"},{"doc":"glacier_demo/glacier_demo_module_d","title":"glacier_demo/glacier_demo_module_d","content":"","url":"glacier_demo/glacier_demo_module_d.html"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_5","content":"pub fn function_5() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_5\nglacier_demo/glacier_demo_module_c function_5","url":"glacier_demo/glacier_demo_module_c.html#function_5"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_6","content":"pub fn function_6() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_6\nglacier_demo/glacier_demo_module_c function_6","url":"glacier_demo/glacier_demo_module_c.html#function_6"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_a","content":"pub fn function_a() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_a\nglacier_demo/glacier_demo_module_c function_a","url":"glacier_demo/glacier_demo_module_c.html#function_a"},{"doc":"glacier_demo/glacier_demo_module_c","title":"glacier_demo/glacier_demo_module_c","content":"","url":"glacier_demo/glacier_demo_module_c.html"},{"doc":"glacier_demo/glacier_demo_module_b","title":"a","content":"pub fn a() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_b.a\nglacier_demo/glacier_demo_module_b a","url":"glacier_demo/glacier_demo_module_b.html#a"},{"doc":"glacier_demo/glacier_demo_module_b","title":"function_3","content":"pub fn function_3() -&gt; Int\n function doc import in_fn_docblock should be ignored\nSynonyms:\nglacier_demo/glacier_demo_module_b.function_3\nglacier_demo/glacier_demo_module_b function_3","url":"glacier_demo/glacier_demo_module_b.html#function_3"},{"doc":"glacier_demo/glacier_demo_module_b","title":"function_4","content":"pub fn function_4() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_b.function_4\nglacier_demo/glacier_demo_module_b function_4","url":"glacier_demo/glacier_demo_module_b.html#function_4"},{"doc":"glacier_demo/glacier_demo_module_b","title":"glacier_demo/glacier_demo_module_b","content":" module doc import in_module_docblock should be ignored","url":"glacier_demo/glacier_demo_module_b.html"},{"doc":"glacier/should","title":"be_error","content":"pub external fn be_error(Result(a, b)) -&gt; b\n\nSynonyms:\nglacier/should.be_error\nglacier/should be_error","url":"glacier/should.html#be_error"},{"doc":"glacier/should","title":"be_false","content":"pub fn be_false(actual: Bool) -&gt; Nil\n\nSynonyms:\nglacier/should.be_false\nglacier/should be_false","url":"glacier/should.html#be_false"},{"doc":"glacier/should","title":"be_ok","content":"pub external fn be_ok(Result(a, b)) -&gt; a\n\nSynonyms:\nglacier/should.be_ok\nglacier/should be_ok","url":"glacier/should.html#be_ok"},{"doc":"glacier/should","title":"be_true","content":"pub fn be_true(actual: Bool) -&gt; Nil\n\nSynonyms:\nglacier/should.be_true\nglacier/should be_true","url":"glacier/should.html#be_true"},{"doc":"glacier/should","title":"equal","content":"pub external fn equal(a, a) -&gt; Nil\n\nSynonyms:\nglacier/should.equal\nglacier/should equal","url":"glacier/should.html#equal"},{"doc":"glacier/should","title":"fail","content":"pub fn fail() -&gt; Nil\n\nSynonyms:\nglacier/should.fail\nglacier/should fail","url":"glacier/should.html#fail"},{"doc":"glacier/should","title":"not_equal","content":"pub external fn not_equal(a, a) -&gt; Nil\n\nSynonyms:\nglacier/should.not_equal\nglacier/should not_equal","url":"glacier/should.html#not_equal"},{"doc":"glacier/should","title":"glacier/should","content":" Based on gleeunit/should, verbatim, renamed to avoid conflicts.\n\n A module for testing your Gleam code. The functions found here are\n compatible with the Erlang eunit test framework.\n\n More information on running eunit can be found in [the rebar3\n documentation](https://rebar3.org/docs/testing/eunit/).","url":"glacier/should.html"},{"doc":"gleeunit2","title":"main","content":"pub fn main() -&gt; Nil\n Find and run all test functions for the current project using Erlang&#39;s EUnit\n test framework.\n\n Any Erlang or Gleam function in the `test` directory with a name editing in\n `_test` is considered a test function and will be run.\n\n If running on JavaScript tests will be run with a custom test runner.\n\nSynonyms:\ngleeunit2.main\ngleeunit2 main","url":"gleeunit2.html#main"},{"doc":"gleeunit2","title":"run","content":"pub fn run(for test_module_files: List(String)) -&gt; Nil\n Runs a specific list of test modules\n\nSynonyms:\ngleeunit2.run\ngleeunit2 run","url":"gleeunit2.html#run"},{"doc":"gleeunit2","title":"gleeunit2","content":"","url":"gleeunit2.html"},{"doc":"glacier","title":"ModuleKind","content":"pub type ModuleKind {\n  SrcModuleKind\n  TestModuleKind\n}\n Atom to internally differentiate between Src and Test modules.\n Public because the FFIs rely on it.\n\nSrcModuleKind\n\n\nTestModuleKind\n\n\nSynonyms:\nglacier.ModuleKind\nglacier ModuleKind","url":"glacier.html#ModuleKind"},{"doc":"glacier","title":"main","content":"pub fn main() -&gt; Nil\n Runs either Glacier or Gleeunit bundled as `gleeunit2`, depending on\n the given command line arguments.\n\nSynonyms:\nglacier.main\nglacier main","url":"glacier.html#main"},{"doc":"glacier","title":"glacier","content":"","url":"glacier.html"},{"doc":"glacier_demo/glacier_demo_module_e","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nglacier_demo/glacier_demo_module_e.main\nglacier_demo/glacier_demo_module_e main","url":"glacier_demo/glacier_demo_module_e.html#main"},{"doc":"glacier_demo/glacier_demo_module_e","title":"glacier_demo/glacier_demo_module_e","content":"","url":"glacier_demo/glacier_demo_module_e.html"}]);